==> nextcloud-app-calendar-1%3A4.5.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es_AR.js <==
OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "La dirección de E Mail proporcionada no es valida",
    "Hello," : "Hola,",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Upcoming events" : "Próximos eventos",
    "Calendar" : "Calendario",
    "Confirm" : "Confirmar",
    "Anniversary" : "Aniversario",
    "Personal" : "Personal",
    "A Calendar app for Nextcloud" : "Una aplicación de calendario para Nextcloud",
    "Previous day" : "Día previo",
    "Previous week" : "Semana previa",
    "Previous month" : "Mes previo",
    "Next day" : "Proximo día",
    "Next week" : "Proxima semana",
    "Next month" : "Proximo mes",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "List" : "Lista",
    "Preview" : "Vista previa",
    "Copy link" : "Copiar enlace",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "New calendar" : "Nuevo calendario",
    "New calendar with task list" : "Nuevo calendario con listado de tareas",
    "Copied link" : "Link copiado",
    "Export" : "Exportar",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Copy internal link" : "Copiar enlace interno",
    "Share link" : "Compartir link",
    "Copy public link" : "Copiar link publico",
    "Copied code" : "Código copiado",
    "can edit" : "puede editar",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "No users or groups" : "No hay usuarios ni grupos.",
    "Save" : "Guardar",
    "Filename" : "Nombre de archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "Show week numbers" : "Mostrar número de semana",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "to" : "para",
    "Add" : "Añadir",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Update" : "Actualizar",
    "Your email address" : "Su dirección de correo electrónico",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "Delete file" : "Borrar archivo",
    "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
    "Available" : "Disponible",
    "Unknown" : "Desconocido",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentative" : "Tentativo",
    "Send email" : "Enviar correo electrónico",
    "All day" : "Todo el día",
    "Repeat" : "Repetir",
    "never" : "nunca",
    "after" : "después",
    "available" : "disponible",
    "More" : "Más",
    "Global" : "Global",
    "Subscribe" : "Suscribirse",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Resources" : "Recursos",
    "Close" : "Cerrar",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Other" : "Otro",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Categories" : "Categoría",
    "Movie" : "Película",
    "Mail" : "Correo Electrónico",
    "Birthday" : "Fecha de nacimiento"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-calendar-1%3A4.6.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es_AR.js <==
OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "La dirección de E Mail proporcionada no es valida",
    "Hello," : "Hola,",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Upcoming events" : "Próximos eventos",
    "Calendar" : "Calendario",
    "Confirm" : "Confirmar",
    "A Calendar app for Nextcloud" : "Una aplicación de calendario para Nextcloud",
    "Previous day" : "Día previo",
    "Previous week" : "Semana previa",
    "Previous month" : "Mes previo",
    "Next day" : "Proximo día",
    "Next week" : "Proxima semana",
    "Next month" : "Proximo mes",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Year" : "Año",
    "List" : "Lista",
    "Preview" : "Vista previa",
    "Copy link" : "Copiar enlace",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "New calendar" : "Nuevo calendario",
    "New calendar with task list" : "Nuevo calendario con listado de tareas",
    "Copied link" : "Link copiado",
    "Export" : "Exportar",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Empty trash bin" : "Vaciar la papelera",
    "Copy internal link" : "Copiar enlace interno",
    "Share link" : "Compartir link",
    "Copy public link" : "Copiar link publico",
    "Copied code" : "Código copiado",
    "can edit" : "puede editar",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "No users or groups" : "No hay usuarios ni grupos.",
    "Save" : "Guardar",
    "Filename" : "Nombre de archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "Show week numbers" : "Mostrar número de semana",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "to" : "para",
    "Add" : "Añadir",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Update" : "Actualizar",
    "Your email address" : "Su dirección de correo electrónico",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "Delete file" : "Borrar archivo",
    "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
    "Available" : "Disponible",
    "Unknown" : "Desconocido",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentative" : "Tentativo",
    "Send email" : "Enviar correo electrónico",
    "All day" : "Todo el día",
    "Repeat" : "Repetir",
    "never" : "nunca",
    "after" : "después",
    "first" : "primero",
    "last" : "último",
    "available" : "disponible",
    "More" : "Más",
    "Global" : "Global",
    "Subscribe" : "Suscribirse",
    "Personal" : "Personal",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Resources" : "Recursos",
    "Close" : "Cerrar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Other" : "Otro",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Categories" : "Categoría",
    "Talk" : "Hablar",
    "Movie" : "Película",
    "Mail" : "Correo Electrónico",
    "Birthday" : "Fecha de nacimiento"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
